@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1002';
+our $VERSION = '0.1100';
 
 use Moo;
 use Music::Chord::Note;
@@ -40,6 +40,12 @@ has format => (
 );
 
 
+has seven => (
+    is      => 'ro',
+    default => sub { 0 },
+);
+
+
 sub cadence {
     my ( $self, %args ) = @_;
 
@@ -182,6 +188,9 @@ sub _generate_chord {
     my $roman = $mtr->parse($note);
     my $type  = $roman =~ /^$diminished{$scale}$/ ? 'dim' : $roman =~ /^[a-z]/ ? 'm' : '';
 
+    $type .= 7
+        if $self->seven;
+
     # Generate the chord notes
     my @notes = $mcn->chord( $note . $type );
 
@@ -219,7 +228,7 @@ Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1002
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -277,6 +286,11 @@ version 0.1002
   );
   # [['B4','D4','G4'], ['E4','G4','C4']]
 
+  $mc = Music::Cadence->new( seven => 1 );
+
+  $chords = $mc->cadence;
+  # [['G','B','D','F'], ['C','E','G','A#','C']]
+
 =head1 DESCRIPTION
 
 C<Music::Cadence> generates a pair of musical cadence chords.
@@ -284,10 +298,6 @@ C<Music::Cadence> generates a pair of musical cadence chords.
 These chords are usually added to the end of a musical phrase, and
 are used to suggest a sense of anticipation, pause, finality, etc.
 
-B<*> This module is a naive implementation of the actual theory.
-Currently, only chords of 3 notes are generated.  YMMV.  Patches
-welcome.
-
 =head1 ATTRIBUTES
 
 =head2 key
@@ -332,6 +342,10 @@ chord generation.
 
 If C<midinum>, convert notes to their numerical MIDI equivalents.
 
+=head2 seven
+
+Use seventh chords (of 4 notes).  Default: C<0>
+
 =head1 METHODS
 
 =head2 new
@@ -343,6 +357,7 @@ If C<midinum>, convert notes to their numerical MIDI equivalents.
     scale  => $scale,
     octave => $octave,
     format => $format,
+    seven  => $seven,
   );
 
 Create a new C<Music::Cadence> object.
@@ -412,6 +427,10 @@ this is:
 If an B<inversion> is defined for the C<half> cadence, the first chord
 is inverted.
 
+=head1 TO DO
+
+Evaded cadence
+
 =head1 SEE ALSO
 
 The F<eg/cadence> and F<t/01-methods.t> files in this distribution.
